@@ -1,19 +1,17 @@
 import os
-from soil.datastucture import SettingsDict
 
 # Load settings
 #-----------------------------------------------------------------------------------------------------------------------
 BEANSTALK_GLOBAL_BASE_PATH = '/etc/beanstalk_stack'
 BEANSTALK_GLOBAL_SETTINGS_PATH = os.path.join(BEANSTALK_GLOBAL_BASE_PATH, 'beanstalk_settings.py')
-BEANSTALK_GLOBAL_SETTINGS = SettingsDict(BEANSTALK_GLOBAL_SETTINGS_PATH)
 
 # Pacakge information
 #-----------------------------------------------------------------------------------------------------------------------
-__version__ = '0.1.0'
+__version__ = '0.1.0.1'
 VERSION = tuple(map(lambda x: int(x), __version__.split('.')))
 BEANSTALK_ROOT_PATH = os.path.abspath(os.path.dirname(__file__))
 
-# Values from settings
+# Values
 #-----------------------------------------------------------------------------------------------------------------------
-IDENTIFIER = BEANSTALK_GLOBAL_SETTINGS.get('IDENTIFIER', 'com.wantoto.beanstalk')
-BEANSTALK_LOCAL_BASE_PATH = BEANSTALK_GLOBAL_SETTINGS.get('LOCAL_BASE_PATH', 'bsbean/')
+IDENTIFIER = 'com.wantoto.beanstalk'
+BEANSTALK_LOCAL_BASE_PATH = 'bsbean/'
